This is an automated email from the ASF dual-hosted git repository.

andy pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/jena.git

commit 5e8d2254f9e093e2d59bb363ba47137257dd606b
Author: Andy Seaborne <[email protected]>
AuthorDate: Wed Dec 31 14:25:26 2025 +0000

    Test type: OmittedTest
---
 .../org/apache/jena/arq/junit/OmittedTest.java     | 44 ++++++++++++++++++++++
 .../apache/jena/arq/junit/sparql/SparqlTests.java  | 24 ++++++------
 2 files changed, 56 insertions(+), 12 deletions(-)

diff --git a/jena-arq/src/test/java/org/apache/jena/arq/junit/OmittedTest.java 
b/jena-arq/src/test/java/org/apache/jena/arq/junit/OmittedTest.java
new file mode 100644
index 0000000000..0dd1098c44
--- /dev/null
+++ b/jena-arq/src/test/java/org/apache/jena/arq/junit/OmittedTest.java
@@ -0,0 +1,44 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.jena.arq.junit;
+
+import org.apache.jena.arq.junit.manifest.ManifestEntry;
+
+/**
+ * Omitted test -= no marked as "suppressed" but not run.
+ */
+public class OmittedTest extends SkipTest {
+    public final boolean verbose;
+
+    public OmittedTest(ManifestEntry entry) {
+        super(entry);
+        this.verbose = false;
+    }
+
+    public OmittedTest(ManifestEntry entry, boolean verbose) {
+        super(entry);
+        this.verbose = verbose;
+    }
+
+    @Override
+    public void runTest() {
+        //if ( verbose )
+            System.err.println("Omitted test: " + manifestEntry.getName());
+    }
+}
diff --git 
a/jena-arq/src/test/java/org/apache/jena/arq/junit/sparql/SparqlTests.java 
b/jena-arq/src/test/java/org/apache/jena/arq/junit/sparql/SparqlTests.java
index 3f552c1a72..7c9480bfb8 100644
--- a/jena-arq/src/test/java/org/apache/jena/arq/junit/sparql/SparqlTests.java
+++ b/jena-arq/src/test/java/org/apache/jena/arq/junit/sparql/SparqlTests.java
@@ -20,6 +20,7 @@ package org.apache.jena.arq.junit.sparql;
 
 import static org.apache.jena.arq.junit.Scripts.entryContainsSubstring;
 
+import org.apache.jena.arq.junit.OmittedTest;
 import org.apache.jena.arq.junit.Scripts;
 import org.apache.jena.arq.junit.SurpressedTest;
 import org.apache.jena.arq.junit.manifest.ManifestEntry;
@@ -109,22 +110,21 @@ public class SparqlTests {
 
         // ---- Query Evaluation Tests
         if ( equalsType(testType, TestManifest.QueryEvaluationTest) ) {
-
-            // tests not supported.
+            // Locally no supported.
+            // Omitted tests.
 
             // ??
-            if ( entryContainsSubstring(entry, 
"aggregates/manifest#agg-groupconcat-04") ) {
-                return null;
-            }
+            if ( entryContainsSubstring(entry, 
"aggregates/manifest#agg-groupconcat-04") )
+                return new OmittedTest(entry);
 
             // Two BNODE in the SELECT
-            if ( entryContainsSubstring(entry, "functions/manifest#bnode01") ) 
{
-                return null;
-            }
-            // Jena bug?
-            if ( entryContainsSubstring(entry, 
"property-path/manifest#values_and_path") ) {
-                return null;
-            }
+            if ( entryContainsSubstring(entry, "functions/manifest#bnode01") )
+                return new OmittedTest(entry);
+            // Jena issue?
+            if ( entryContainsSubstring(entry, 
"property-path/manifest#values_and_path") )
+                return new OmittedTest(entry);
+
+            // Query evaluation tests.
             return new QueryEvalTest(entry);
         }
         if ( equalsType(testType, TestManifestX.TestQuery) )

Reply via email to